//von Bertalanffy growth model
//For MNADMB Short Course 1, August 2007
//Created by T. Brenden

DATA_SECTION
//Read in data from growth.dat
  init_int nobs  //number of observations
  init_matrix fish(1,nobs,1,2)  //observed ages

  init_int test  //data reading test values 

  //!!cout << fish << endl;
  //!!exit(13);
PARAMETER_SECTION
//Parameters to be estimated in model
  init_number log_Linf  //asymptotic length (log scale)
  init_number log_K  //growth coefficient (log scale)
  init_number log_sigma
  init_number t0  //age at which length is 0cm

//Quantities to be calculated from parameters
  number K  //Brody growth coefficient
  number Linf //asymptotic size
  number sigma
  vector ages(1,nobs)
  vector length_obs(1,nobs)
  vector length_pred(1,nobs)  //predicted mean length-at-age
  number rss  //residual sum of squares

// The objective function - we will minimize negative log concentrated likelihood  
  objective_function_value neg_LL  //negative log concentrated concentrated likelihood

INITIALIZATION_SECTION
//Starting values for parameters
  log_Linf 7.0
  log_K -0.9
  t0 -0.1
  log_sigma 7.0

PRELIMINARY_CALCS_SECTION
  ages=column(fish,1);
  length_obs=column(fish,2);

PROCEDURE_SECTION
//Bactransform parameter
  K=exp(log_K);
  Linf=exp(log_Linf);
  sigma=exp(log_sigma);

//von Bertalanffy growth model
  length_pred=Linf*(1.0-exp(-K*(ages-t0)));

//Objective function defined
  rss=norm2(length_obs-length_pred); //residual sum of squares
  neg_LL=nobs*log(sigma)+(0.5/square(sigma))*rss; //negative log concentrated likelihood

REPORT_SECTION
//Output to growth.rep
  report << "Predicted mean length-at-age" << endl;
  report << length_pred << endl;
  report << "Observed mean length-at-age" << endl;
  report << length_obs << endl;
  report << "L infinity equals: " << Linf << endl;
  report << "Kappa equals: " << K << endl;
  report << "t0 equals: " << t0 << endl;
  report << "Sigma square equals: " << square(sigma) << endl;

