//Linearized Ricker stock recruit curve
//Developed for Huron Ontario salmonid stocking research project
//Created 4-13-07 by T.Brenden
//Last modified 4-13-07 by T. Brenden

//Any text after "//" is ignored

DATA_SECTION
//Read in data from "ADMB_recruit.dat" file
  init_int nobs  //number of observations in data set
  init_vector year(1,nobs) //list of data years
  init_vector spawners(1,nobs)  //spawners
  init_vector recruits(1,nobs)  //recruits
  init_int test
//!!cout << test << endl;
//!!exit(88);

PARAMETER_SECTION
//Parameters to be estimated in model
  init_number alpha 
  init_number beta
  init_number lnsigma

//Quantities to be calculated from parameters
  vector logRoverS(1,nobs)  //log recruits over spawners
  vector logRoverS_pred(1,nobs)  //predicted logRoverS
  number rss
  number sigma
//The objective function - we will minimize negative log concentrated likelihood
  objective_function_value neg_LL

INITIALIZATION_SECTION
  alpha 3.0
  beta 0.0
  lnsigma 1.0

PRELIMINARY_CALCS_SECTION
  logRoverS = log(elem_div(recruits,spawners));
  //cout << logRoverS << endl;
  //exit(88);

PROCEDURE_SECTION
//Linearized version of Ricker stock recruit
  sigma=exp(lnsigma);
  logRoverS_pred=alpha+beta*spawners;
  rss=norm2(logRoverS-logRoverS_pred);
  neg_LL=nobs*log(sigma)+(0.5/square(sigma))*rss;

REPORT_SECTION
  report << "Sigma square estimate equals " << square(sigma) << endl;
  report << "Intercept estimate equals " << alpha << endl;
  report << "Slope estimate equals " << beta << endl;
