//Minnesota ADMB Mortality Model

DATA_SECTION
//Read in data from "mortality.dat" file
  init_int N1  //number of tagged fish in 1960
  init_int N2  //number of tagged fish in 1961
  init_int N3  //number of tagged fish in 1962
  init_int N4  //number of tagged fish in 1963
  init_int N5  //number of tagged fish in 1964
  init_int R11  //number of recovered 1960 cohort in year 1
  init_int R12  //number of recovered 1960 cohort in year 2
  init_int R13  //number of recovered 1960 cohort in year 3
  init_int R14  //number of recovered 1960 cohort in year 4
  init_int R15  //number of recovered 1960 cohort in year 5
  init_int R22  //number of recovered 1961 cohort in year 1
  init_int R23  //number of recovered 1961 cohort in year 2
  init_int R24  //number of recovered 1961 cohort in year 3
  init_int R25  //number of recovered 1961 cohort in year 4
  init_int R33  //number of recovered 1962 cohort in year 1
  init_int R34  //number of recovered 1962 cohort in year 2
  init_int R35  //number of recovered 1962 cohort in year 3
  init_int R44  //number of recovered 1963 cohort in year 1
  init_int R45  //number of recovered 1963 cohort in year 2
  init_int R55  //number of recovered 1964 cohort in year 1
  init_number test //Dummy vector
//!!cout << test << endl;
//!!exit(5);


PARAMETER_SECTION
//Parameters to be estimated in model
  init_bounded_number log_F1(-0.9,0,4)  //instantaneous year 1 fishing mortality (log scale)
  init_bounded_number log_F2(-0.9,0,4)  //instantaneous year 2 fishing mortality (log scale)
  init_bounded_number log_F3(-0.9,0,4)  //instantaneous year 3 fishing mortality (log scale)
  init_bounded_number log_F4(-0.9,0,4)  //instantaneous year 4 fishing mortality (log scale)
  init_bounded_number log_F5(-0.9,0,4)  //instantaneous year 5 fishing mortality (log scale)
  init_bounded_number log_M(-2.3,-0.9)  //instantaneous natural mortality (log scale)

//Quantities to be calculated from parameters
  sdreport_number F1  //instantaneous fishing mortality
  sdreport_number F2  //instantaneous fishing mortality
  sdreport_number F3  //instantaneous fishing mortality
  sdreport_number F4  //instantaneous fishing mortality
  sdreport_number F5  //instantaneous fishing mortality
  sdreport_number M //instantaneous natural mortality

  number L1  //concentrated likelihood for 1960 tagging cohort
  number L2  //concentrated likelihood for 1961 tagging cohort
  number L3  //concentrated likelihood for 1961 tagging cohort
  number L4  //concentrated likelihood for 1961 tagging cohort
  number L5  //concentrated likelihood for 1961 tagging cohort

  number p11 //probability for 1960 cohort year 1 recapture
  number p12 //probability for 1960 cohort year 2 recapture
  number p13 //probability for 1960 cohort year 3 recapture
  number p14 //probability for 1960 cohort year 4 recapture
  number p15 //probability for 1960 cohort year 5 recapture 
  number p22 //probability for 1961 cohort year 1 recapture
  number p23 //probability for 1961 cohort year 2 recapture
  number p24 //probability for 1961 cohort year 3 recapture
  number p25 //probability for 1961 cohort year 4 recapture
  number p33 //probability for 1962 cohort year 1 recapture
  number p34 //probability for 1962 cohort year 2 recapture
  number p35 //probability for 1962 cohort year 3 recapture
  number p44 //probability for 1963 cohort year 1 recapture
  number p45 //probability for 1963 cohort year 2 recapture
  number p55 //probability for 1964 cohort year 1 recapture


// The objective function - we will minimize negative log concentrated likelihood  
  objective_function_value conc_like  //negative log concentrated concentrated likelihood

INITIALIZATION_SECTION
//Starting values for parameters
  log_F1 -0.7
  log_F2 -0.7
  log_F3 -0.7
  log_F4 -0.7
  log_F5 -0.7
  log_M -0.7

PROCEDURE_SECTION
//Backtransform parameter
  F1=exp(log_F1);
  F2=exp(log_F2);
  F3=exp(log_F3);
  F4=exp(log_F4);
  F5=exp(log_F5);
  M=exp(log_M);
  p11 = 0.18*(F1/(F1+M))*(1-exp(-F1-M));
  p12 = 0.18*(F2/(F2+M))*(1-exp(-F2-M))*exp(-F1-M);
  p13 = 0.18*(F3/(F3+M))*(1-exp(-F3-M))*exp(-F1-F2-2*M);
  p14 = 0.18*(F4/(F4+M))*(1-exp(-F4-M))*exp(-F1-F2-F3-3*M);
  p15 = 0.18*(F5/(F5+M))*(1-exp(-F5-M))*exp(-F1-F2-F3-F4-4*M);
  p22 = 0.18*(F2/(F2+M))*(1-exp(-F2-M));
  p23 = 0.18*(F3/(F3+M))*(1-exp(-F3-M))*exp(-F2-M);
  p24 = 0.18*(F4/(F4+M))*(1-exp(-F4-M))*exp(-F2-F3-2*M);
  p25 = 0.18*(F5/(F5+M))*(1-exp(-F5-M))*exp(-F2-F3-F4-3*M); 
  p33 = 0.18*(F3/(F3+M))*(1-exp(-F3-M));
  p34 = 0.18*(F4/(F4+M))*(1-exp(-F4-M))*exp(-F3-M);
  p35 = 0.18*(F5/(F5+M))*(1-exp(-F5-M))*exp(-F3-F4-2*M);
  p44 = 0.18*(F4/(F4+M))*(1-exp(-F4-M));
  p45 = 0.18*(F5/(F5+M))*(1-exp(-F5-M))*exp(-F4-M);
  p55 = 0.18*(F5/(F5+M))*(1-exp(-F5-M));

  L1 = R11*log(p11)+R12*log(p12)+R13*log(p13)+R14*log(p14)+R15*log(p15)+(N1-R11-R12-R13-R14-R15)*log(1-p11-p12-p13-p14-p15);

  L2 = R22*log(p22)+R23*log(p23)+R24*log(p24)+R25*log(p25)+(N2-R22-R23-R24-R25)*log(1-p22-p23-p24-p25);

  L3 = R33*log(p33)+R34*log(p34)+R35*log(p35)+(N3-R33-R34-R35)*log(1-p33-p34-p35);

  L4 = R44*log(p44)+R45*log(p45)+(N4-R44-R45)*log(1-p44-p45);

  L5 = R55*log(p55)+(N5-R55)*log(1-p55);

  conc_like = -L1-L2-L3-L4-L5-0.5*square((log((M/0.2))/0.1));

  if (mceval_phase())
  {
  cout << F1 << " " << F2 << " " <<  F3 << " " << F4 << " " << F5 << " " << M << endl;
  }


REPORT_SECTION
//By default every thing in this section gets written to the file "mortality.rep"
//Characters in quotation marks are written out as text
  report << "Estimate of F1" << endl;
  report << F1  << endl;
  report << "Estimate of F2" << endl;
  report << F2 << endl;
  report << "Estimate of F3" << endl;
  report << F3 << endl;
  report << "Estimate of F4" << endl;
  report << F4 << endl;
  report << "Estimate of F5" << endl;
  report << F5 << endl;
  report << "Estimate of M" << endl;
  report << M  << endl;
