//von Bertalanffy growth model
//For MNADMB Short Course 1, August 2007
//Created by T. Brenden

DATA_SECTION
//Read in data from growth.dat
  init_int nobs  //number of observations
  init_matrix fish(1,nobs,1,2)  //observed ages

  init_int test  //data reading test values 

  //!!cout << fish << endl;
  //!!exit(13);
  int icount

PARAMETER_SECTION
//Parameters to be estimated in model
  init_bounded_number Linf(500,2000)  //asymptotic length (log scale)
  init_bounded_number K(0.01,0.9)  //growth coefficient (log scale)
  init_number t0  //age at which length is 0cm


//Age and Length vectors
  vector ages(1,nobs)
  vector length_obs(1,nobs)

//Quantities to be calculated from parameters
  vector length_pred(1,nobs)  //predicted mean length-at-age
  number rss  //residual sum of squares

// The objective function - we will minimize negative log concentrated likelihood  
  objective_function_value c_like  //negative log concentrated concentrated likelihood

INITIALIZATION_SECTION
//Starting values for parameters
  Linf 1200.0
  K 0.4
  t0 -0.1

PRELIMINARY_CALCS_SECTION
  ages = column(fish,1);
  length_obs=column(fish,2);
  //cout << length_obs << endl;
  //cout << ages << endl;
  //exit(14);

PROCEDURE_SECTION

//von Bertalanffy growth model
  length_pred=Linf*(1.0-exp(-K*(ages-t0)));
  rss=0;

  for(icount=1;icount<=nobs;icount++)
  {
  rss+=square(length_obs(icount)-length_pred(icount));
  }

//Objective function defined
  c_like=(nobs/2.0)*log(rss); //negative log concentrated likelihood

REPORT_SECTION
//Output to growth.rep
  report << "Predicted mean length-at-age" << endl;
  report << length_pred << endl;
  report << "Observed mean length-at-age" << endl;
  report << length_obs << endl;
  report << Linf << endl;
