//Control program for statistical catch-at-age analysis
//Simulate observed data with two levels of catchability variation
//For ADMB Short Course 2, August 2006
//Created by B. Linton

GLOBALS_SECTION
//Variables declared in global section are valid everywhere in model

//Variables for making report file names
//"char" object holds character string of specified length
  char charlvl[5];  //hold catchability variation level
  char charrep[5];  //hold replicate number
  char filename[25];  //hold dat file name
  char appcommand[100];  //hold append command

DATA_SECTION
//Read in data from master.dat
  init_int nlvl  //number of levels of log catchability sd
  init_int nrep  //number of replicate data sets
  init_int fyear  //first year
  init_int lyear  //last year
  init_int fage  //first age
  init_int lage  //last age
  init_int nages_plus //number of ages to create plus group in first year
  init_number recruit_avg  //average recruitment
  init_number log_recruit_sd  //sd of log recruitment
  init_number M  //natural mortality
  init_vector effort(fyear,lyear)  //fishing effort 
  init_vector select(fage,lage)  //selectivity
  init_number q  //catchabitlity
  init_vector log_q_sd(1,nlvl)  //sd of log catchability
  init_number log_total_catch_sd  //sd of log total catch
  init_number Nsample  //effective sample size for catch age composition
  init_int rnseed  //initial random number seed
  init_vector test(1,3)  //data entry test values

//Calculated quantities
  int seed  //current random number seed

//Looping variables
  int i  //loop over catchability variation levels
  int j  //loop over replicate data sets

//Check that data reads in correctly
  //!!cout << test << endl;
  //!!exit(5);

PARAMETER_SECTION
//Need one active parameter for model to run
  init_number dummy
//Need objective function value for model to compile
  objective_function_value fake

PRELIMINARY_CALCS_SECTION
//Delete old output files
  system("del true.rep");
  system("del predicted.rep");

//Loop over levels of catchability variation
  for (i=1;i<=nlvl;i++)
  {
    //Set current random number seed to initial value
    seed=rnseed;

    //Loop over replicate data sets
    for (j=1;j<=nrep;j++)
    {
      //Create simulate.dat file
      get_datfile();

      //Run simulate.exe to create catch.dat
      system("simulate");

      //Append true population values for each replicate to true.rep
      system ("cat temp.dat >> true.rep");

      //Run catch.exe to fit model to simulated data
      system("catch -nox");

      //Append estimation model results to unique report file
      get_command();  //creates append command
      system (appcommand);

      //Append estimation model results to predicted.rep
      //system ("cat catch.rep >> predicted.rep");

      //Update random number seed for next replicate data set
      seed+=5;
    }
  }

//Exit before ADMB attempts to estimate dummy parameter
  exit(0);
  
PROCEDURE_SECTION

FUNCTION get_datfile
//This function creates simulate.dat file
//Most values are simply passed from master.dat
  ofstream data("simulate.dat");  //"data" command reads out to simulate.dat
  data << i << " " << j << endl;  //Unique ID for a replicate data set
  data << fyear << " " << lyear << endl;
  data << fage << " " << lage << endl;
  data <<  nages_plus << endl;
  data << recruit_avg << " " << log_recruit_sd << endl;
  data << M << endl;
  data << effort << endl; 
  data << select << endl;
  data << q << " " << log_q_sd(i) << endl;  //output current log catchability sd value
  data << log_total_catch_sd << " " << Nsample << endl;
  data << seed << endl;  //output current random number seed value
  data << test(1,3) << endl;

FUNCTION get_command
//This function creates command to append results to unique report file

  //Create unique report file name
  sprintf(charlvl,"%i",i);  //convert numerical value of i to character string
  sprintf(charrep,"%i",j);  //convert numerical value of j to character string
  strcpy(filename,"catch");  //copy string "catch" to filename
  strcat(filename,charlvl);  //concatenate charnlvl to filename
  strcat(filename,charrep);  //concatenate charrep to filename
  strcat(filename,".rep");  //concatenate string ".rep" to filename

  //Create command to append results to unique report file
  strcpy(appcommand,"cat catch.rep >> ");  //copy string "cat catch.rep << " to runcommand
  strcat(appcommand,filename);  //concatenate filename to runcommand

